@@ -53,6 +53,7 @@ def make_node(
         input_bias = get_constant_or_variable(
             graph_node.inputs[2],
             before_op_output_shape_trans,
+            is_bias=True,
         )
     graph_node_output: gs.Variable = graph_node.outputs[0]
     shape = graph_node_output.shape
@@ -234,6 +235,10 @@ def make_node(
                     'input': input_tensor,
                     'weights': input_weights,
                     'bias': input_bias,
+                    'strides': strides,
+                    'dilations': dilations,
+                    'padding': pad_mode,
+                    'group': group,
                 },
                 'tf_outputs': {
                     'output': tf_layers_dict[graph_node_output.name]['tf_node'],
