@@ -5,16 +5,21 @@ np.random.seed(0)
 import tensorflow as tf
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
+    get_replacement_parameter,
+    replace_parameter,
     get_constant_or_variable,
     convert_axis,
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -72,6 +77,29 @@ def make_node(
             tf.reduce_prod(input_tensor_shape[0:axis]),
             tf.reduce_prod(input_tensor_shape[axis:tf.size(input_tensor_shape)]),
         )
+
+    # Param replacement
+    transposed_tensor = replace_parameter(
+        value_before_replacement=transposed_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+    cal_shape = replace_parameter(
+        value_before_replacement=cal_shape,
+        param_target='attributes',
+        param_name='axis',
+        **kwargs,
+    )
+
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.reshape(
             tensor=input_tensor,
@@ -79,6 +107,14 @@ def make_node(
             name=graph_node.name,
         )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
